@@ -49,57 +49,65 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                           ),
                           sidebarLayout(
                             sidebarPanel(width = 4,
-                            tabsetPanel(id = "ES_family", type = "pills",
-                                        tabPanel("Non-overlap", 
-                                        br(),
-                                        selectInput("NOM_ES", 
-                                                    label = "Effect size index",
-                                                    choices = c("IRD",
-                                                                "NAP",
-                                                                "PAND",
-                                                                "PEM",
-                                                                "PND",
-                                                                "Tau",
-                                                                "Tau-U" = "Tau_U"), 
-                                                    selected = "NAP"),
-                                        selectInput("improvement",
-                                                    label = "Direction of improvement",
-                                                    choices = c("increase", "decrease"))),
-                                        tabPanel("Parametric", 
-                                        br(),
-                                        selectInput("parametric_ES", 
-                                                    label = "Effect size index", 
-                                                    choices = c("LOR", "LRRd", "LRRi","SMD"), 
-                                                    selected = "LRRd"),
-                                        selectInput("improvement",
-                                                    label = "Direction of improvement",
-                                                    choices = c("increase", "decrease")),
-                                        conditionalPanel(condition = "input.parametric_ES == 'SMD'",
-                                                        radioButtons("SMD_denom", 
-                                                                     label = "Standardized by", 
-                                                                     choices = c("baseline SD","pooled SD"))),
-                                        conditionalPanel(condition = "input.parametric_ES=='LOR'|input.parametric_ES=='LRRi'|input.parametric_ES=='LRRd'",
-                                                         selectInput("outScale", label = "Outcome Scale",
-                                                                     choices = c("percentage", 
-                                                                                 "proportion",
-                                                                                 "count",
-                                                                                 "rate",
-                                                                                 "other")),
-                                                         numericInput("intervals", label = "If observed via interval recording, total intervals per session", value = NULL)),
-                                        conditionalPanel(condition = "input.parametric_ES=='LRRi'|input.parametric_ES=='LRRd'",
-                                                        numericInput("obslength", label = "Session length (in minutes)", value = NULL)),
-                                        conditionalPanel(condition = "input.parametric_ES=='LOR'|input.parametric_ES=='LRRi'|input.parametric_ES=='LRRd'",
-                                                        numericInput("lrrfloor", label = "User-specified floor constant",value = NULL))),
-                                        conditionalPanel(condition = "input.ES_family=='Parametric'|input.NOM_ES=='NAP'|input.NOM_ES=='Tau'",
-                                                        numericInput("confidence", 
-                                                                     label = "Confidence level", 
-                                                                     value = 95, 
-                                                                     min = 0, 
-                                                                     max = 100)),
-                                         numericInput("digits","Digits",
-                                                      value = 3, min = 1, 
-                                                      max = 16, step = 1))),
+                              tabsetPanel(id = "ES_family", type = "pills",
+                                          tabPanel("Non-overlap", 
+                                            br(),
+                                            selectInput("NOM_ES", 
+                                                        label = "Effect size index",
+                                                        choices = c("IRD",
+                                                                    "NAP",
+                                                                    "PAND",
+                                                                    "PEM",
+                                                                    "PND",
+                                                                    "Tau",
+                                                                    "Tau-U" = "Tau_U"), 
+                                                        selected = "NAP")
+                                          ),
+                                          tabPanel("Parametric", 
+                                            br(),
+                                            selectInput("parametric_ES", 
+                                                        label = "Effect size index", 
+                                                        choices = c("LOR", "LRRd", "LRRi","SMD"), 
+                                                        selected = "LRRd"),
+                                            conditionalPanel(condition = "input.parametric_ES=='LRRi'|input.parametric_ES=='LRRd'",
+                                                             checkboxInput("pct_change","Convert LRR to % change"))
+                                          )
+                              ),
+                              selectInput("improvement",
+                                          label = "Direction of improvement",
+                                          choices = c("increase", "decrease")),
+                              conditionalPanel("input.ES_family=='Parametric'",
+                                 conditionalPanel(condition = "input.parametric_ES == 'SMD'",
+                                                  radioButtons("SMD_denom", 
+                                                               label = "Standardized by", 
+                                                               choices = c("baseline SD","pooled SD"))),
+                                 conditionalPanel(condition = "input.parametric_ES=='LOR'|input.parametric_ES=='LRRi'|input.parametric_ES=='LRRd'",
+                                                  selectInput("outScale", label = "Outcome Scale",
+                                                              choices = c("percentage", 
+                                                                          "proportion",
+                                                                          "count",
+                                                                          "rate",
+                                                                          "other")),
+                                                  numericInput("intervals", label = "If observed via interval recording, total intervals per session", value = NULL)),
+                                 conditionalPanel(condition = "input.parametric_ES=='LRRi'|input.parametric_ES=='LRRd'",
+                                                  numericInput("obslength", label = "Session length (in minutes)", value = NULL)),
+                                 conditionalPanel(condition = "input.parametric_ES=='LOR'|input.parametric_ES=='LRRi'|input.parametric_ES=='LRRd'",
+                                                  numericInput("lrrfloor", label = "User-specified floor constant",value = NULL))
+                              ),
+                              conditionalPanel(condition = "input.ES_family=='Parametric'|input.NOM_ES=='NAP'|input.NOM_ES=='Tau'",
+                                  numericInput("confidence", 
+                                               label = "Confidence level", 
+                                               value = 95, 
+                                               min = 0, 
+                                               max = 100)
+                              ),
+                              numericInput("digits","Digits",
+                                          value = 2, min = 1, 
+                                          max = 16, step = 1)
+                            ),
                             mainPanel(width = 8,
+                                      conditionalPanel(condition = "input.ES_family=='Non-overlap' & input.NOM_ES == 'PND'", 
+                                                       includeMarkdown("markdown/PND-message.md")),
                                       htmlOutput("result"),
                                       checkboxInput("explanation", 
                                                     label = "Show methods and references", 
@@ -148,7 +156,7 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                                        sidebarPanel(
                                          style = "max-height: 800px; overflow-y: auto",
                                          uiOutput("clusterPhase"),
-                                         uiOutput("phaseDefine"),
+                                         uiOutput("baseDefine"),
                                          uiOutput("treatDefine"),
                                          uiOutput("outOrderImp"),
                                          conditionalPanel(condition = "input.bimprovement == 'series'",
@@ -163,7 +171,10 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                                          h4("Select Effect Sizes"),
                                          checkboxGroupInput("bESno", "Non-Overlap Effect Sizes", choices = c("IRD","NAP","PAND","PEM","PND","Tau","Tau-U" = "Tau_U"), inline = TRUE),
                                          checkboxGroupInput("bESpar", "Parametric Effect Sizes", choices = c("LOR", "LRRd", "LRRi" ,"SMD"),inline = TRUE),
-                                         conditionalPanel(condition = "input.bESpar.includes('LOR')", HTML("<font color=\"#FF0000\">LOR will only be calculated for outcomes measured as percentages or proportions.</font>")),
+                                         conditionalPanel(condition = "input.bESpar.includes('LRRi') | input.bESpar.includes('LRRd') | input.bESpar.includes('LOR')",
+                                                          checkboxInput("b_pct_change", "Convert LRR to % change")),
+                                         conditionalPanel(condition = "input.bESpar.includes('LOR')", 
+                                                          HTML("<font color=\"#FF0000\">LOR will only be calculated for outcomes measured as percentages or proportions.</font>")),
                                          conditionalPanel(condition = "input.bESpar.includes('SMD')", 
                                                           radioButtons("bSMD_denom", label = "Standardize SMD ", 
                                                                        choices = c("baseline SD" = "baseline", "pooled SD" = "pool"), inline = TRUE)),
@@ -175,11 +186,14 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                                                           actionButton("batchest", "Estimate"))
                                        ),
                                        
-                                       mainPanel(tableOutput("batchTable"),
-                                                 p(),
-                                                 conditionalPanel(condition = "input.batchest > 0",
-                                                                  downloadButton("downloadES", label = "Download results"))
-                                                 )
+                                       mainPanel(
+                                         conditionalPanel(condition = "input.bESno.includes('PND')", 
+                                                          includeMarkdown("markdown/PND-message.md")),
+                                         tableOutput("batchTable"),
+                                         p(),
+                                         conditionalPanel(condition = "input.batchest > 0",
+                                                          downloadButton("downloadES", label = "Download results"))
+                                       )
                                     )
                                      
                             )
